# Quil

⚠️ In Development

The `quil` Python package provides tools for
constructing, manipulating, parsing, and printing [Quil][quil-spec] programs.
Internally, it is powered by [`quil-rs`][].

It should be considered unstable until the release of v1.0.

## Documentation

Documentation for the current release of `quil` is published [here][quil-py-docs].
Every version of `quil` ships [with type stubs][quil-py-stubs]
that provide type hints and documentation to Python tooling
and editors that support the [Language Server Protocol][] or similar.

[quil-spec]: https://github.com/quil-lang/quil
[`quil-rs`]: https://github.com/rigetti/quil-rs/quil-rs
[quil-py-docs]: https://rigetti.github.io/quil-rs/quil.html
[quil-py-stubs]: https://github.com/rigetti/quil-rs/tree/main/quil-rs/python/quil
[Language Server Protocol]: https://microsoft.github.io/language-server-protocol/
